==> cramr_ui_lib-0.0.12.tar.gz: test/widgets/text_checker_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/widgets/text_checker.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

main() {
  testWidgets('test the behaviour of the stack', (WidgetTester tester) async {
    VerbTestModel model = VerbTestModel();
    model.initialise(_randomIndicative, _randomPronouns, 'fr',
        _randomInfinitive, 'translation');
    const int defaultPerson = 0;
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext context) {
          return model;
        },
        child: const MaterialApp(
          home: TextChecker(
            currentPerson: defaultPerson,
          ),
        )));
    Finder pronounFinder = find.text(_randomPronouns[defaultPerson]);
    expect(pronounFinder, findsOneWidget);
    Finder iconFinder = find.byKey(const Key('comparisonStatusIcon'));
    expect(iconFinder, findsOneWidget);
    testIconColor(tester, iconFinder, Colors.grey);
    Finder textFieldFinder = find.byKey(const Key('actualVerb'));
    expect(textFieldFinder, findsOneWidget);
    await tester.enterText(
        textFieldFinder, _randomIndicative[defaultPerson].substring(0, 2));
    await tester.pumpAndSettle();
    testIconColor(tester, iconFinder, Colors.orange);
    await tester.enterText(textFieldFinder, 'completelywrong');
    await tester.pumpAndSettle();
    testIconColor(tester, iconFinder, Colors.red);
    await tester.enterText(textFieldFinder, _randomIndicative[defaultPerson]);
    await tester.pumpAndSettle();
    testIconColor(tester, iconFinder, Colors.green);
  });
}

void testIconColor(WidgetTester tester, Finder iconFinder, Color color) {
  expect((tester.firstWidget(iconFinder) as Icon).color, color);
}

==> cramr_ui_lib-0.0.14.tar.gz: test/widgets/text_checker_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/widgets/text_checker.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

main() {
  testWidgets('test the behaviour of the stack', (WidgetTester tester) async {
    VerbTestModel model = VerbTestModel();
    model.initialise(_randomIndicative, _randomPronouns, 'fr',
        _randomInfinitive, 'translation');
    const int defaultPerson = 0;
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext context) {
          return model;
        },
        child: const MaterialApp(
          home: TextChecker(
            currentPerson: defaultPerson,
          ),
        )));
    Finder pronounFinder = find.text(_randomPronouns[defaultPerson]);
    expect(pronounFinder, findsOneWidget);
    Finder iconFinder = find.byKey(const Key('comparisonStatusIcon'));
    expect(iconFinder, findsOneWidget);
    testIconColor(tester, iconFinder, Colors.grey);
    Finder textFieldFinder = find.byKey(const Key('actualVerb_0'));
    expect(textFieldFinder, findsOneWidget);
    await tester.enterText(
        textFieldFinder, _randomIndicative[defaultPerson].substring(0, 2));
    await tester.pumpAndSettle();
    testIconColor(tester, iconFinder, Colors.orange);
    await tester.enterText(textFieldFinder, 'completelywrong');
    await tester.pumpAndSettle();
    testIconColor(tester, iconFinder, Colors.red);
    await tester.enterText(textFieldFinder, _randomIndicative[defaultPerson]);
    await tester.pumpAndSettle();
    testIconColor(tester, iconFinder, Colors.green);
  });
}

void testIconColor(WidgetTester tester, Finder iconFinder, Color color) {
  expect((tester.firstWidget(iconFinder) as Icon).color, color);
}
